<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_va
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aide_non_disponible' => 'Aquela part de l’ajua en linha es pas encara disponibla per aquesta lenga.',
	'avis_acces_interdit' => 'Accès proïbit.',
	'avis_article_modifie' => 'Atencion, @nom_auteur_modif@ a trabalhat sus aquel article fai @date_diff@ minutas',
	'avis_aucun_resultat' => 'Pas ges de resultat.',
	'avis_chemin_invalide_1' => 'Lo chamin qu’avètz chausit',
	'avis_chemin_invalide_2' => 'sembla pas valid. Volhatz tornar vèrs la pagina anteriora per verificar las informacions fornias.',
	'avis_connexion_echec_1' => 'La connexion au servior SQL a mal capitat.', # MODIF
	'avis_connexion_echec_2' => 'Tornatz vèrs la pagina anteriora, e verificatz las informacions qu’avètz fornias.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Sus ben de serviors, devètz <b>demandar</b> qu’activen vòstre accès vèrs la basa SQL avans de la poer utilizar. Se vos poètz pas connectar, verificatz qu’aiatz ben realizat aquel procediment.', # MODIF
	'avis_connexion_ldap_echec_1' => 'La connexion au servior LDAP a mal capitat.',
	'avis_connexion_ldap_echec_2' => 'Tornatz a la pagina anteriora, e verificatz las informacions qu’avètz fornias. ',
	'avis_connexion_ldap_echec_3' => 'Alternativament, utilizetz pas lo supòrt LDAP per importar d’utilizaires.',
	'avis_deplacement_rubrique' => 'Atention! Aquela rubrica conten @contient_breves@ brèvas@scb@: se la desplaçatz, voudretz ben oschar aquela casa de confirmacion.',
	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
	'avis_espace_interdit' => '<b>Espaci proïbit</b><p>SPIP es ja installat.', # MODIF
	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion a pas pogut legir los noms de las basas de donaas installaas.',
	'avis_lecture_noms_bases_2' => 'Siá ges de basa es pas disponibla, siá la foncion que permet d’entierar las basas es estaa desactivaa per de rasons de seguretat (aquò’s lo cas en cò de mai d’un auberjaor).',
	'avis_lecture_noms_bases_3' => 'Dins la segonda alternativa, es probable qu’una basa que pòrta vòstre nom de login siá utilizabla:',
	'avis_non_acces_page' => 'Poètz pas accedir vèrs aquela pagina.',
	'avis_operation_echec' => 'L’operacion a mal capitat.',
	'avis_suppression_base' => 'ATENCION, suprimir las donaas es irreversible',

	// B
	'bouton_acces_ldap' => 'Apondre l’accès a LDAP >>',
	'bouton_ajouter' => 'Apondre',
	'bouton_demande_publication' => 'Demandar la publicacion d’aquest article',
	'bouton_effacer_tout' => 'Esfaçar tot',
	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Afichar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dins la tiera dels redactors connectats',
	'bouton_radio_envoi_annonces_adresse' => 'Mandar los anoncis a l’adreiça:',
	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tiera de las novetats',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Pas aparéisser dins la tiera dels redactors',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Pas mandar d’anoncis editorials',
	'bouton_redirection' => 'TORNAR DIRIGIR',
	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
	'bouton_suivant' => 'Seguent',
	'bouton_tenter_recuperation' => 'Assajar de reparar',
	'bouton_test_proxy' => 'Assajar lo proxy',
	'bouton_vider_cache' => 'Voidar l’escondeor',

	// C
	'cache_modifiable_webmestre' => 'Lo webmèstre dau sit pòt modificar aquestes paramètres.',
	'calendrier_synchro' => 'S’utilizatz un logicial d’agenda compatible <b>iCal</b> (Apple iCal, Mozilla Calendar, Ximian Evolution, KOrganizer...), lo poètz sincronizar amb l’actualitat dau sit.',

	// D
	'date_mot_heures' => 'oras',

	// E
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'entree_adresse_annuaire' => 'Adreiça de l’annuari',
	'entree_adresse_email' => 'Vòstra adreiça e-mail',
	'entree_base_donnee_1' => 'Adreiça de la basa de donaas',
	'entree_base_donnee_2' => '(Sovent, aquela adreiça correspònd a aquela de vòstre sit, de viatges correspònd a la mençon "localhost", de viatges, se laissa voida completament.)',
	'entree_biographie' => 'Biografia brèva, en quauques mots.',
	'entree_chemin_acces' => '<b>Intrar</b> lo chamin d’accès:',
	'entree_cle_pgp' => 'Vòstra clau PGP',
	'entree_contenu_rubrique' => '(Contengut de la rubrica en quauques mots.)',
	'entree_identifiants_connexion' => 'Vòstres identificants de connexion...',
	'entree_informations_connexion_ldap' => 'Volhatz intrar dins aquel formulari las informacions de connexion a vòstre annuari LDAP.
L’administrator dau sistèma o de la ret vos deu poer fornir
 aquelas informacions.',
	'entree_infos_perso' => 'Cu siatz?',
	'entree_interieur_rubrique' => 'Dedins la rubrica:',
	'entree_liens_sites' => '<b>Liam ipertèxt</b> (referéncia, sit de vesitar...)',
	'entree_login' => 'Vòstre login',
	'entree_login_connexion_1' => 'Lo login de connexion',
	'entree_login_connexion_2' => '(Correspònd de viatges a vòstre login d’accès vèrs l’FTP; de viatges se laissa voide)',
	'entree_mot_passe' => 'Vòstre senhal',
	'entree_mot_passe_1' => 'Senhau per la connexion',
	'entree_mot_passe_2' => '(Correspònd de viatges a vòstre senhal per l’FTP; de viatges se laissa voide)',
	'entree_nom_fichier' => 'Vougatz intrar lo nom dau fichier @texte_compresse@:',
	'entree_nom_pseudo' => 'Vòstre nom o vòstre pseudonim',
	'entree_nom_pseudo_1' => '(Vòstre nom o vòstre pseudonim)',
	'entree_nom_site' => 'Lo nom de vòstre sit',
	'entree_nouveau_passe' => 'Mot de santa Clara novèl',
	'entree_passe_ldap' => 'Senhal',
	'entree_port_annuaire' => 'Lo numèro de pòrt de l’annuari',
	'entree_signature' => 'Signatura',
	'entree_titre_obligatoire' => '<b>Títol</b> [Obligatòri]<br />',
	'entree_url' => 'L’adreiça (URL) de vòstre sit',

	// I
	'ical_info1' => 'Aquela pagina mòstra de metòdes diferents per restar en contacte amb la vida d’aquel sit.',
	'ical_info2' => 'Per tenir mai d’informacions sobre aquelas tecnicas, esitetz pas de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'I a dos chalendiers a la vòstra disposicion. Lo primier es un plan dau sit qu’anóncia totes los articles publicats. Lo segond conten los anoncis editoriaus en mai de vòstres darriers messatges privats: vos es reservat gràcias a una clau personala, que la poètz modificar en tot moment en renovant vòstre senhau. ',
	'ical_methode_http' => 'Telecharjament',
	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
	'ical_texte_js' => 'Los articles publicats en aqueu sit se pòon afichar aisat, dins totes los sits vòstres, en fasent servir una linha javascript. ',
	'ical_texte_prive' => 'Aquel chalendier, d’us estrictament personal, vos informa de l’activitat editoriala privaa d’aquel sit (òbras e rendètz-vos personals, articles e brèvas prepausats...).',
	'ical_texte_public' => 'Aquel chalendier vos permet de seguir l’activitat publica d’aquel sit (articles e brèvas publicats).',
	'ical_texte_rss' => 'Poètz sindicar las novetats d’aquest sit dins quin legior de fichiers que siá en format XML/RSS (Rich Site Summary). Es pereu lo format que permet a SPIP de legir las novetats publicaas dins d’autres sits en utilizant un format d’eschambi compatible (sits sindicats).  ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de corrier',
	'ical_titre_rss' => 'Fichiers «backend»',
	'icone_activer_cookie' => 'Activar lo cookie de correspondéncia',
	'icone_afficher_auteurs' => 'Afichar los autors',
	'icone_afficher_visiteurs' => 'Afichar los vesitaires',
	'icone_arret_discussion' => 'Quitar aquela discussion',
	'icone_calendrier' => 'Chalendier',
	'icone_creer_auteur' => 'Crear un autor nòu e l’associar a aquel article',
	'icone_creer_mot_cle' => 'Crear un mot clau nòu e lo liar a aquel article',
	'icone_creer_rubrique_2' => 'Crear una rubrica nòva',
	'icone_modifier_article' => 'Modificar aquel article',
	'icone_modifier_rubrique' => 'Modificar aquela rubrica',
	'icone_retour' => 'Tornar',
	'icone_retour_article' => 'Tornar a l’article',
	'icone_supprimer_cookie' => 'Suprimir lo cookie de correspondéncia',
	'icone_supprimer_rubrique' => 'Suprimir aquela rubrica',
	'icone_supprimer_signature' => 'Suprimir aquela signatura',
	'icone_valider_signature' => 'Validar aquela signatura',
	'image_administrer_rubrique' => 'Poètz administrar aquela rubrica',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 article',
	'info_activer_cookie' => 'Poètz activar un <b>cookie de correspondéncia</b>; aquò vos permetrà de passar aisat dau sit public au sit privat.',
	'info_administrateur' => 'Administrator',
	'info_administrateur_1' => 'Administrator',
	'info_administrateur_2' => 'dau sit(<i>d’utilizar amb precaucion</i>)',
	'info_administrateur_site_01' => 'Se siatz administrator/tritz dau sit, volhatz',
	'info_administrateur_site_02' => 'clicar aquel liam',
	'info_administrateurs' => 'Administrators',
	'info_administrer_rubrique' => 'Poètz administrar aquela rubrica',
	'info_adresse' => 'a l’adreiça:',
	'info_adresse_url' => 'Adreiça (URL) dau sit public',
	'info_aide_en_ligne' => 'Ajua en linha SPIP',
	'info_ajout_image' => 'Quand apondètz d’imatges coma estachaments jonches a un article, SPIP pòt crear automaticament per vos de vinhetas (miniaturas) dels imatges inserits. Aquò permet per exemple de crear automaticament una galariá o un pòrtfòlio.',
	'info_ajouter_rubrique' => 'Apondre una autra rubrica d’administrar:',
	'info_annonce_nouveautes' => 'Anonci de las novetats',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Los articles pòstdatats per paréisser',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Los articles d’aquel autor',
	'info_articles_trouves' => 'Articles trobats',
	'info_attente_validation' => 'Vòstres articles en espèra de validacion',
	'info_aujourdhui' => 'encuei:',
	'info_auteurs' => 'Los autors',
	'info_auteurs_par_tri' => 'autors@partri@',
	'info_auteurs_trouves' => 'Autors trobats',
	'info_authentification_externe' => 'Autentificacion extèrna',
	'info_avertissement' => 'Avís',
	'info_base_installee' => 'L’estructura de vòstra basa de donaas es installaa.',
	'info_chapeau' => 'Chapèl',
	'info_chapeau_2' => 'Chapèl:',
	'info_chemin_acces_1' => 'Opcions: <b>chamin d’accès dins l’annuari</b>',
	'info_chemin_acces_2' => 'Aüra devètz configurar lo chamin d’accès vèrs las informacions dins l’annuari.',
	'info_chemin_acces_annuaire' => 'Opcions:<b>chamin d’accès dins l’annuari',
	'info_choix_base' => 'Tresena estapa:',
	'info_classement_1' => '<sup>ier</sup> de @liste@',
	'info_classement_2' => '<sup>nd</sup> de @liste@',
	'info_code_acces' => 'Eissublietz pas vòstres còdes d’accès pròpris!',
	'info_config_suivi' => 'S’aquela adreiça correspònd a una lista de corrier, poètz indicar çai sos l’adreiça ont los participants au sit se pòon inscriure. Aquela adreiça pòt èstre una URL (per exemple la pagina d’inscripcion a la lista per lo web), o una adreiça e-mail tenent un subjècte especific (per exemple: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Poètz recebre automaticament, per e-mail, los anoncis pertochant l’activitat editoriala d’aquel sit. Per aquò faire, vos poètz abonar a la lista de corrier seguenta:',
	'info_confirmer_passe' => 'Confirmar aquel mot de santa Clara novèl:',
	'info_connexion_base' => 'Segonda estapa: <b>Assai de connexion a la basa</b>',
	'info_connexion_ldap_ok' => 'La connexion LDAP a abotit.</b><p> Poètz passar a l’estapa seguenta.', # MODIF
	'info_connexion_mysql' => 'Primiera estapa:<b>Vòstra connexion SQL</b>',
	'info_connexion_ok' => 'La connexion a abotit.',
	'info_contact' => 'Contacte',
	'info_contenu_articles' => 'Contengut dels articles',
	'info_creation_paragraphe' => '(Per crear de paragrafes, sufís que laissetz de linhas voidas.)', # MODIF
	'info_creation_rubrique' => 'Avans de poer escriure d’articles,<br /> devètz crear aumens una rubrica.<br />',
	'info_creation_tables' => 'Quatrena estapa: <b>Creacion de las taulas de la basa</b>',
	'info_creer_base' => '<b>Crear</b> una basa de donaas novèla:',
	'info_dans_rubrique' => 'Dins la rubrica:',
	'info_date_publication_anterieure' => 'Data anteriora de publicacion:',
	'info_date_referencement' => 'DATA DE REFERENCIAMENT D’AQUEL SIT:',
	'info_derniere_etape' => 'Darriera estapa: <b>Aquò’s achabat!',
	'info_descriptif' => 'Descriptiu:',
	'info_discussion_cours' => 'Discussions en cors',
	'info_ecrire_article' => 'Avans de poer escriure d’articles, vos chau crear aumens una rubrica.',
	'info_email_envoi' => 'Adreiça e-mail d’enviament (opcional)',
	'info_email_envoi_txt' => 'Indicatz aicí l’adreiça d’utilizar per enviar los e-mails (a fauta d’aquò, s’utilizarà l’adreiça destinatari coma adreiça d’enviament):',
	'info_email_webmestre' => 'Adreiça e-mail dau responsable dau sit (opcional)', # MODIF
	'info_envoi_email_automatique' => 'Enviament d’e-mails automatics',
	'info_envoyer_maintenant' => 'Mandar aüra',
	'info_etape_suivante' => 'Passar a l’estapa seguenta',
	'info_etape_suivante_1' => 'Poètz passar a l’estapa seguenta.',
	'info_etape_suivante_2' => 'Poètz passar a l’estapa seguenta.',
	'info_exportation_base' => 'exportacion de la basa vèrs @archive@',
	'info_facilite_suivi_activite' => 'Per facilitar lo seguit de l’activitat editoriala dau sit, SPIP vos pòt fornir per e-mail, per exemple a una lista de corrier dels redactors, l’anonci de las demandas de publicacion e de las validacions d’articles.', # MODIF
	'info_fichiers_authent' => 'Fichiers d’autentificacion « .htpasswd »',
	'info_forums_abo_invites' => 'Vòstre sit web òfre de forums per los abonats; dins lo sit public los vesitaires son convidats a se registrar.',
	'info_gauche_admin_tech' => '<b>A aquela pagina, mas que los responsables dau sit i pòon accedir.</b><p> Permet de trobar las diferentas foncions de mantenença tecnica. Quauques unas implican un procès d’autentificacion especific, que necessita un accès FTP vèrs lo sit web.</p>', # MODIF
	'info_gauche_admin_vider' => '<b>A aquela pagina, mas que los responsables dau sit i pòon accedir.</b><p> Permet de trobar las diferentas foncions de mantenença tecnica. Quauques unas implican un procès d’autentificacion especific, que necessita un accès FTP vèrs lo sit web.</p>', # MODIF
	'info_gauche_auteurs' => 'Trobaretz aicí totes los autors dau sit. La color de las icònas n’indica l’estatut (administrator = verd; redactor = jaune).',
	'info_gauche_auteurs_exterieurs' => 'Los autors exteriors, sens accès vèrs lo sit, son indicats amb una icòna blava; los autors esfaçats amb un bordilhier.', # MODIF
	'info_gauche_messagerie' => 'La messatjariá vos permet d’eschambiar de mementos (per vòstre usatge personal) o d’afichar d’anoncis sus la pagina d’acuelh de l’espaci privat (se siatz administrator/tritz).',
	'info_gauche_statistiques_referers' => 'Aquela pagina presenta la lista dels <i>referiors</i>, aquò vòu dire dels sits que contenon de liams que menan vèrs vòstre sit pròpri, mas unicament au jorn d’encuei: aquela lista s’actualiza chasca 24 oras.',
	'info_gauche_visiteurs_enregistres' => 'Trobaretz aquí los vesitaires registrats
 dins l’espaci public dau sit (forums amb abonament).',
	'info_generation_miniatures_images' => 'Congreacion de miniaturas dels imatges',
	'info_hebergeur_desactiver_envoi_email' => 'Quauques auberjaors desactivan l’enviament automatic
 d’e-mails dempuei lors serviors. En aqueu cas, las foncionalitats seguentas
 d’SPIP foncionaràn pas.',
	'info_hier' => 'ièr:',
	'info_identification_publique' => 'Vòstra identitat publica...',
	'info_image_process' => 'Volhatz seleccionar lo melhor metòde de fabricacion de las vinhetas en clicar sus l’imatge correspondent.',
	'info_image_process2' => '<b>N.B.</b> <i>Se ges d’imatge apareis, aladonc lo servior qu’aubèrja vòstre sit l’an pas configurat per utilizar d’aisinas talas. Se desiratz d’utilizar aquelas foncions, contactatz lo responsable tecnic e demandatz las extensions «GD» o «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imatges calculats automaticament',
	'info_informations_personnelles' => 'Cinquena estapa: <b>Informacions personalas</b>',
	'info_inscription_automatique' => 'Inscripcion automatica de redactors novèls',
	'info_jeu_caractere' => 'Juec de caractèrs dau sit',
	'info_jours' => 'jorns',
	'info_laisser_champs_vides' => 'laissar aqueles champs voides)',
	'info_langues' => 'Lengas dau sit',
	'info_ldap_ok' => 'L’autentificacion LDAP es installaa.',
	'info_lien_hypertexte' => 'Liam ipertèxt:',
	'info_liste_redacteurs_connectes' => 'Tiera dels redactors connectats',
	'info_login_existant' => 'Aquel login ja existís.',
	'info_login_trop_court' => 'Login tròp cort.',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'Dins la mesma rubrica',
	'info_message_en_redaction' => 'Vòstres messatges en cors de redaccion',
	'info_message_technique' => 'Messatge tecnic:',
	'info_messagerie_interne' => 'Messatjariá intèrna',
	'info_mise_a_niveau_base' => 'Mesa a nivèu de vòstra basa SQL',
	'info_mise_a_niveau_base_2' => '{{Atencion!}} Avètz installaa una version
  dels fichiers SPIP {anteriora} a la que i aviá
  avans sobre aquest sit: riscatz de pèrdre vòstra basa de donaas
   e vòstre sit foncionarà pas pus.<br />{{Tornatz installar los
  fichiers d’SPIP.}}',
	'info_modifier_rubrique' => 'Modificar la rubrica:',
	'info_modifier_titre' => 'Modificar: @titre@',
	'info_mon_site_spip' => 'Mon sit SPIP',
	'info_moyenne' => 'mejana:',
	'info_multi_cet_article' => 'Lenga d’aquest article:',
	'info_multi_langues_choisies' => 'Volhatz seleccionar çai sos las lengas que son a posita dels redactors de vòstre sit.
  Las lengas ja emplejaas dins vòstre sit (afichaas primieras) se pòon pas desactivar.',
	'info_multi_secteurs' => '... mas que per las rubricas a la raiç dau sit?',
	'info_nom' => 'Nom',
	'info_nom_destinataire' => 'Nom dau destinatari',
	'info_nom_site' => 'Nom de vòstre sit',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
	'info_nombre_sites' => '@nb_sites@ sits,',
	'info_non_deplacer' => 'De pas desplaçar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pòt mandar, regularament, l’anonci de las darrieras novetats dau sit
 (articles e brèvas publicats recentament).',
	'info_non_envoi_liste_nouveautes' => 'Pas mandar la tiera de las novetats',
	'info_non_modifiable' => 'se pòt pas modificar',
	'info_non_suppression_mot_cle' => 'vòlo pas suprimir aquel mot clau.',
	'info_notes' => 'Nòtas',
	'info_nouvel_article' => 'Article nòu',
	'info_nouvelle_traduction' => 'Reviraa nòva:',
	'info_numero_article' => 'ARTICLE NUMÈRO:',
	'info_obligatoire_02' => '[Obligatòri]', # MODIF
	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion dels vesitaires dau sit public',
	'info_option_ne_pas_accepter_visiteurs' => 'Refusar l’inscripcion de vesitaires',
	'info_options_avancees' => 'OPCIONS AVANÇAAS',
	'info_ou' => 'o... ',
	'info_page_interdite' => 'Pagina proïbia',
	'info_par_nombre_article' => '(per nombre d’articles)',
	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
	'info_passes_identiques' => 'Los dos mots de santa Clara son pas identics.',
	'info_plus_cinq_car' => 'mai de 5 caractèrs',
	'info_plus_cinq_car_2' => '(mai de 5 caractèrs)',
	'info_plus_trois_car' => '(mai de 3 caractèrs)',
	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_post_scriptum' => 'Post-scriptum',
	'info_post_scriptum_2' => 'Post-scriptum:',
	'info_pour' => 'per',
	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avián publicat totes los articles e brèvas (que tenon aumens l’estatut "prepausat"). La chal dobrir, aquela possibilitat, als administrators solament, a totes los redactors, o a degun?', # MODIF
	'info_procedez_par_etape' => 'procedissètz estapa per estapa',
	'info_procedure_maj_version' => 'Chal lançar la procedura d’actualizacion per adaptar
 la basa de donaas a la version novèla d’SPIP.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Vòstres articles publicats en linha',
	'info_question_accepter_visiteurs' => 'S’a las esqueletas de vòstre sit web se prevei lo registrament de vesitaires sens accès a l’espaci privat, volhatz activar l’opcion seguenta:',
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptatz que de redactors novèls s’inscrivan
 a partir dau sit public? Se o acceptatz, los vesitaires se poiràn inscriure
 gràcias a un formulari automatizat e doncas accediràn a l’espaci privat per
 prepausar d’articles.<blockquote><i> Durant la fasa d’inscripcion, los utilizaires recebon un e-mail automatic
 que lor baila un còde d’accès vèrs lo sit privat.
Quauques auberjaors autorizan pas l’enviament d’e-mails dempuei lors serviors: en aqueu cas, l’inscripcion automatica es
 impossibla.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Raiç dau sit',
	'info_recharger_page' => 'Volhatz tornar charjar aquela pagina dins un momenton.',
	'info_recherche_auteur_zero' => '<b>Ges de resultat trobat per "@cherche_auteur@".',
	'info_recommencer' => 'Volhatz tornar començar.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'qu’accedís vèrs l’espaci privat (<i>recomandat</i>)',
	'info_redacteurs' => 'Redactors',
	'info_redaction_en_cours' => 'EN CORS DE REDACCION',
	'info_redirection' => 'Redireccion',
	'info_refuses' => 'Vòstres articles refusats',
	'info_reglage_ldap' => 'Opcions: <b>Reglatge de l’importacion LDAP</b>',
	'info_renvoi_article' => '<b>Redireccion.</b> Aquel article remanda a la pagina:',
	'info_reserve_admin' => 'Mas los administrators pòon modificar aquela adreiça.',
	'info_restreindre_rubrique' => 'Restrénher la gestion a la rubrica:',
	'info_resultat_recherche' => 'Resultats de la cèrcha:',
	'info_rubriques' => 'Rubricas',
	'info_rubriques_02' => 'rubricas',
	'info_rubriques_trouvees' => 'Rubricas trobaas',
	'info_sans_titre' => 'Sens títol',
	'info_selection_chemin_acces' => '<b>Seleccionatz</b> çai sos lo chamin d’accès dins l’annuari:',
	'info_signatures' => 'signaturas',
	'info_site' => 'Sit',
	'info_site_2' => 'sit: ',
	'info_site_min' => 'sit',
	'info_site_reference_2' => 'Sit referenciat',
	'info_site_web' => 'SIT WEB:', # MODIF
	'info_sites' => 'sits',
	'info_sites_lies_mot' => 'Los sits referenciats liats a aquel mot clau',
	'info_sites_proxy' => 'Utilizar un proxy',
	'info_sites_trouves' => 'Sits trobats',
	'info_sous_titre' => 'Sostítol:',
	'info_statut_administrateur' => 'Administrator',
	'info_statut_auteur' => 'Estatut d’aquel autor:', # MODIF
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estatut predefinit dels utilizaires importats',
	'info_statut_utilisateurs_2' => 'Chausissètz l’estatut d’atribuir a las personas presentas dins l’annuari LDAP quand se connèctan per lo primier viatge. Poiretz puei modificar aquel estatut per chasque autor un cas per un.',
	'info_suivi_activite' => 'Seguit de l’activitat editoriala',
	'info_surtitre' => 'Sobretítol:',
	'info_taille_maximale_vignette' => 'Talha maximala de las vinhetas congreaas per lo sistèma:',
	'info_terminer_installation' => 'Aüra poètz achabar la procedura d’installacion estandard.',
	'info_texte' => 'Tèxt',
	'info_texte_explicatif' => 'Tèxt explicatiu',
	'info_texte_long' => '(lo tèxt es lòng: apareis doncas en talhons distints que se tornaràn empejar un còp validats.)',
	'info_texte_message' => 'Tèxt de vòstre messatge:', # MODIF
	'info_texte_message_02' => 'Tèxt dau messatge',
	'info_titre' => 'Títol:',
	'info_total' => 'total: ',
	'info_tous_articles_en_redaction' => 'Totes los articles en cors de redaccion',
	'info_tous_articles_presents' => 'Totes los articles publicats dins aquela rubrica',
	'info_tous_les' => 'totes los:',
	'info_tout_site' => 'Tot lo sit ',
	'info_tout_site2' => 'An pas revirat l’article dins aquela lenga.',
	'info_tout_site3' => 'An revirat l’article dins aquela lenga, mas an portat puei de modificacions a l’article de referéncia. Chal actualizar la reviraa.',
	'info_tout_site4' => 'An revirat l’article dins aquela lenga, e la reviraa es actualizaa.',
	'info_tout_site5' => 'Article original.',
	'info_tout_site6' => '<b>Atencion:</b> mas que los articles originals s’afichan.
Las reviraas s’assòcian a l’original,
una color indica lor estat:',
	'info_travail_colaboratif' => 'Trabalh collaboratiu sobre los articles',
	'info_un_article' => 'un article, ',
	'info_un_site' => 'un sit, ',
	'info_une_rubrique' => 'una rubrica, ',
	'info_une_rubrique_02' => '1 rubrica',
	'info_url' => 'URL:',
	'info_urlref' => 'Liam ipertèxt:',
	'info_utilisation_spip' => 'Aüra poètz començar d’utilizar lo sistèma de publicacion assistia...',
	'info_visites_par_mois' => 'Afichatge per mes:',
	'info_visiteur_1' => 'Vesitaire',
	'info_visiteur_2' => 'dau sit public',
	'info_visiteurs' => 'Vesitaires',
	'info_visiteurs_02' => 'Vesitaires dau sit public',
	'install_echec_annonce' => 'L’installacion capitarà mau, o abotirà a un sit non foncionau...',
	'install_extension_mbstring' => 'SPIP fonciona pas amb:',
	'install_extension_php_obligatoire' => 'SPIP exigís l’extension php:',
	'install_select_langue' => 'Seleccionatz una lenga puei clicatz lo boton «seguent» per amodar la procedura d’installacion.',
	'intem_redacteur' => 'redactor',
	'item_accepter_inscriptions' => 'Acceptar las inscripcions',
	'item_activer_messages_avertissement' => 'Activar los messatges d’avertiment',
	'item_administrateur_2' => 'administrator',
	'item_afficher_calendrier' => 'Afichar dins lo chalendier',
	'item_choix_administrateurs' => 'los administrators',
	'item_choix_generation_miniature' => 'Congrear automaticament las miniaturas dels imatges.',
	'item_choix_non_generation_miniature' => 'Pas congrear de miniaturas dels imatges.',
	'item_choix_redacteurs' => 'los redactors',
	'item_choix_visiteurs' => 'los vesitaires dau sit public',
	'item_creer_fichiers_authent' => 'Crear de fichiers .htpasswd',
	'item_login' => 'Login',
	'item_mots_cles_association_articles' => 'als articles',
	'item_mots_cles_association_rubriques' => 'a las rubricas',
	'item_mots_cles_association_sites' => 'als sits referenciats o sindicats',
	'item_non' => 'Non ',
	'item_non_accepter_inscriptions' => 'Pas acceptar las inscripcions',
	'item_non_activer_messages_avertissement' => 'Ges de messatge d’avertiment',
	'item_non_afficher_calendrier' => 'De pas afichar dins lo chalendier',
	'item_non_creer_fichiers_authent' => 'Pas crear aqueles fichiers',
	'item_non_publier_articles' => 'Pas publicar los articles avans la data de publicacion prevista.',
	'item_nouvel_auteur' => 'Autor nòu',
	'item_nouvelle_rubrique' => 'Rubrica nòva',
	'item_oui' => 'Òc',
	'item_publier_articles' => 'Publicar los articles, quina que siá lor data de publicacion',
	'item_reponse_article' => 'Respònsa a l’article',
	'item_visiteur' => 'vesitaire',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'lien_ajouter_auteur' => 'Apondre aquel autor',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NOM DAU SIT:',
	'lien_retirer_auteur' => 'Levar l’autor',
	'lien_site' => 'sit',
	'lien_tout_deplier' => 'Desplejar tot',
	'lien_tout_replier' => 'Tornar plejar',
	'lien_trier_nom' => 'Triar per nom',
	'lien_trier_nombre_articles' => 'Triar per nombre d’articles',
	'lien_trier_statut' => 'Triar per estatut',
	'lien_voir_en_ligne' => 'VEIRE EN LINHA:',
	'logo_article' => 'LÒGO DE L’ARTICLE', # MODIF
	'logo_auteur' => 'LÒGO DE L’AUTOR', # MODIF
	'logo_rubrique' => 'LÒGO DE LA RUBRICA', # MODIF
	'logo_site' => 'LÒGO D’AQUEU SIT', # MODIF
	'logo_standard_rubrique' => 'LÒGO ESTANDARD DE LAS RUBRICAS', # MODIF
	'logo_survol' => 'LÒGO PER LO SOBREVÒU', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Chausia de vòstra basa',
	'module_fichier_langue' => 'Fichier de lenga',
	'module_raccourci' => 'Acorcha',
	'module_texte_affiche' => 'Tèxt afichat',
	'module_texte_explicatif' => 'Poètz inserir las acorchas seguentas dins las esqueletas de vòstre sit public. Se reviraràn automaticament  dins las diferentas lengas per las qualas existís un fichier de lenga.',
	'module_texte_traduction' => 'Lo fichier de lenga «@module@» es disponible en:',
	'mois_non_connu' => 'non conegut',

	// O
	'onglet_repartition_actuelle' => 'd’aquesta passa',

	// R
	'required' => '[Obligatòri]', # MODIF

	// S
	'statut_admin_restreint' => '(admin. restrench)', # MODIF

	// T
	'taille_cache_image' => 'Los imatges qu’SPIP a calculat automaticament (vinhetas dels documents, títols presentats en forma grafica, foncions matematicas en format TeX...) ocupan dins lo repertòri @dir@ un totau de @taille@.',
	'taille_cache_infinie' => 'Aqueu sit prevei ges de limitacion de talha dau repertòri <code>CACHE/</code>.',
	'taille_cache_maxi' => 'SPIP assaia de limitar la talha dau repertòri <code>CACHE/</code> d’aqueu sit a <b>@octets@</b> de donaas environ.',
	'taille_cache_octets' => 'Aüra la talha de l’escondeor compassa @octets@.', # MODIF
	'taille_cache_vide' => 'L’escondeor es vueid.',
	'taille_repertoire_cache' => 'Talha dau repertòri escondeor',
	'text_article_propose_publication' => 'Article prepausat per la publicacion. Esitetz pas de donar vòstre avís gràcias au forum estachat a aquel article (en bas de pagina).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'Quauques serviors LDAP accèptan ges d’accès anonim. En aqueu cas, chau especificar un identificant d’accès iniciau per poer puei cerchar d’informacions dins l’annuari. Pasmens, los champs seguents se poiràn laissar voides dins la màger part dels cases.',
	'texte_admin_effacer_01' => 'Aquela comanda esfaça <i>tot</i> lo contengut de la basa de donaas,
 incluses <i>tots</i> los accèsses redactors e administrators. Un còp que l’auretz executaa, auretz de tornar lançar l’installacion d’SPIP per tornar crear una basa novèla e mai un primier accès administrator.',
	'texte_adresse_annuaire_1' => '(Se vòstre annuari es installat sobre la mesma maquina qu’aqueu sit web, s’agís probable de "localhost".)',
	'texte_ajout_auteur' => 'L’autor seguent es estat apondut a l’article:',
	'texte_annuaire_ldap_1' => 'S’accedissètz a un annuari (LDAP), lo poètz utilizar per importar automaticament d’utilizaires sos SPIP.',
	'texte_article_statut' => 'Aquel article es:',
	'texte_article_virtuel' => 'Article virtuau',
	'texte_article_virtuel_reference' => '<b>Article virtuau:</b> article referenciat dins vòstre sit SPIP, mas redirigit vèrs una autra URL. Per suprimir la redireccion, esfaçatz l’URL çai sobre.',
	'texte_aucun_resultat_auteur' => 'Ges de resultat per "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Aquest sit vos pòt indicar de contunha la tiera dels redactors connectats, çò que vos permet d’eschambiar de messatges en dirècte. Poètz decidir de pas aparéisser dins aquela lista (siatz "invisible/a" per los autres utilizaires).',
	'texte_auteurs' => 'LOS AUTORS',
	'texte_choix_base_1' => 'Chausissètz vòstra basa:',
	'texte_choix_base_2' => 'Lo servior SQL conten mai d’una basa de donaas.',
	'texte_choix_base_3' => '<b>Chausissètz</b> çai sos aquela que vòstre auberjaor vos a atribuïa:',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elements',
	'texte_connexion_mysql' => 'Consultatz las informacions que vòstre auberjaor fornís: i devètz trobar, se vòstre auberjaor supòrta SQL, los còdes de connexion au servior SQL.', # MODIF
	'texte_contenu_article' => '(Contengut de l’article en quauques mots.)',
	'texte_contenu_articles' => 'Segon la maqueta que vòstre sit a adoptaa, poètz decidir
 que quauques elements dels articles s’utilizen pas.
 Utilizatz la tiera çai sos per indicar quins elements son disponibles.',
	'texte_crash_base' => 'Se vòstra basa de donaas a
 mau capitat, poètz assajar una reparacion
 automatica.',
	'texte_creer_rubrique' => 'Avans de poer escriure d’articles,<br /> devètz crear una rubrica.',
	'texte_date_creation_article' => 'DATA DE CREACION DE L’ARTICLE:',
	'texte_date_publication_anterieure' => 'DATA DE PUBLICACION ANTERIORA',
	'texte_date_publication_anterieure_nonaffichee' => 'Afichar ges de data de publicacion anteriora.',
	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA :',
	'texte_descriptif_rapide' => 'Descriptiu rapid',
	'texte_effacer_base' => 'Esfaçar la basa de donaas SPIP',
	'texte_en_cours_validation' => 'Se prepausa de publicar los articles e brèvas çai sos. Esitetz pas per donar vòstre avís gràcias als forums que i son estachats.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Poètz enrichir la compaginacion de vòstre tèxt en utilizant d’"acorchas tipograficas".',
	'texte_fichier_authent' => '<b>Deu crear, SPIP, de fichiers especiaus  <tt>.htpasswd</tt>
  e <tt>.htpasswd-admin</tt> dins lo repertòri @dossier@ ?</b><p>
  Aqueles fichiers vos pòon servir per restrénher l’accès als autors
  e administrators autra part dins vòstre sit
  (programa extèrne d’estadisticas, per exemple).<p>
 Se vos sèrv pas, poètz laissar aquesta opcion
  a sa valor predefinia (ges de creacion
  dels fichiers).', # MODIF
	'texte_informations_personnelles_1' => 'Aüra lo sistèma vos crearà un accès personalizat au sit.',
	'texte_informations_personnelles_2' => '(Nòta: se s’agís d’una reïnstallacion, e se vòstre accès fonciona encara, poètz', # MODIF
	'texte_introductif_article' => '(Tèxt introductiu de l’article.)',
	'texte_jeu_caractere' => 'Aquesta opcion es utila se vòstre sit deu afichar d’alfabets
 diferents de l’alfabet latin (o "occidentau") e sos derivats.
 En aqueu cas, vau mai chambiar lo reglatge predefinit per 
 un juec de caractèrs apropriat. Com que siá vos conselham de far d’assais
 per fin de trobar una solucion satisfasenta. Se modificatz aqueu paramètre, eissublietz pas nimai d’adaptar
 lo sit public en consequéncia (balisa <tt>#CHARSET</tt>).',
	'texte_login_ldap_1' => '(Laissar voide per un accès anonim, o picar lo chamin complet, per exemple «<tt>uid=fabre, ou=usanciers, dc=mon-domeni, dc=com</tt>».)',
	'texte_login_precaution' => 'Atencion! Aquò’s lo login amb lo quau siatz aüra connectat/aa. 
 Utilizatz aquest formulari amb precaucion...',
	'texte_mise_a_niveau_base_1' => 'Venètz d’actualizar los fichiers SPIP.
 Aüra chau metre a nivèu la basa de donaas
 dau sit.',
	'texte_modifier_article' => 'Modificar l’article:',
	'texte_multilinguisme' => 'Se desiratz de gerir d’articles en mai d’una lenga, amb una navigacion complèxa, poètz apondre un menut per chausir la lenga dels articles e/o de las rubricas, en foncion de l’organizacion de vòstre sit.', # MODIF
	'texte_multilinguisme_trad' => 'Poètz activar pereu un sistèma de gestion dels liams entre las diferentas reviraas d’un article.', # MODIF
	'texte_non_compresse' => '<i>non comprimit</i> (perque vòstre servior supòrta pas aquela foncionalitat)',
	'texte_nouvelle_version_spip_1' => 'Avètz installaa una version novèla d’SPIP.',
	'texte_nouvelle_version_spip_2' => 'Aquesta version novèla demanda una actualizacion mai completa que de costuma. Se siatz webmèstre/webmèstra dau sit, volhatz esfaçar lo fichier <tt>inc_connect.php3</tt> dau repertòri <tt>ecrire</tt> e tornar prene l’installacion a fin d’actualizar vòstres paramètres de connexion a la basa de donaas.<p> (NB: s’avètz eissubliat vòstres paramètres de connexion, agachatz lo fichier  <tt>inc_connect.php3</tt> avans de lo suprimir...)</p>', # MODIF
	'texte_operation_echec' => 'Tornatz a la pagina precedenta, chausissètz una autra basa o creatz-ne’n una novèla. Verificatz las informacions que vòstre auberjaor a fornias.',
	'texte_plus_trois_car' => 'mai de 3 caractèrs',
	'texte_plusieurs_articles' => 'Mai d’un autor trobat per "@cherche_auteur@":',
	'texte_port_annuaire' => '(La valor indicaa coma predefinia conven en generau.)',
	'texte_proposer_publication' => 'Quand auretz achabat vòstre article,<br /> poiretz prepausar que siá publicat.',
	'texte_proxy' => 'Dins quauques cas (intranet, rets protegias...),
  se pòt que chalha utilizar un <i>proxy HTTP</i> per aténher los sits sindicats.
  En aqueu cas, marcatz çai sos son adreiça, sos la forma
  <tt><html>http://proxy:8080</html></tt>. En generau,
  laissaretz voida aquela casa.',
	'texte_publication_articles_post_dates' => 'Coma SPIP se deu comportar fàcia als articles que lor
  data de publicacion es fixaa a una 
  eschaiença futura?',
	'texte_rappel_selection_champs' => '[Eissublietz pas de seleccionar aqueu champ correctament.]',
	'texte_recalcul_page' => 'Se volètz
tornar calcular mas qu’una pagina, passatz puslèu per l’espaci public e utilizatz lo boton "tornar calcular".',
	'texte_recuperer_base' => 'Reparar la basa de donaas',
	'texte_reference_mais_redirige' => 'article referenciat dins vòstre sit SPIP, mas redirigit vèrs una autra URL.',
	'texte_requetes_echouent' => '<b>Quand quauques requistas SQL capitan mau
  sistematicament e sensa rason aparenta, se pòt
  qu’aquò vena ben de la basa de donaas.  </b><p>
  SQL ten la facultat de reparar sas
  taulas quand un accident las
 a gastaas. Aicí poètz assaiar aquela reparacion;
  s’abotís pas, servatz una còpia de l’afichatge, que conten
 benlèu d’indicis de çò que vai pas...<p>
  Se lo problèma persistís, contactatz vòstre
  auberjaor.<p>', # MODIF
	'texte_selection_langue_principale' => 'Poètz seleccionar çai sos la "lenga principala" dau sit. Aquela chausia vos obliga pas -per fortuna- d’escriure vòstres articles dins la lenga seleccionaa, mas permet de determinar:
 <ul><li> lo format predefinit de las datas sobre lo sit public;</li>
 <li> la natura dau motor tipografic que SPIP deu utilizar per lo rendut dels tèxtes;</li>
 <li> la lenga utilizaa dins los formularis dau sit public;</li>
 <li> la lenga presentaa coma predefinia dins l’espaci privat.</li></ul>',
	'texte_sous_titre' => 'Sostítol',
	'texte_statistiques_visites' => '(barras escuras:  dimenge / corba escura: evolucion de la mejana)',
	'texte_statut_attente_validation' => 'en espèra de validacion',
	'texte_statut_publies' => 'publicats en linha',
	'texte_statut_refuses' => 'refusats',
	'texte_suppression_fichiers' => 'Utilizatz aquela comanda per suprimir tots los fichiers que se tròban
dins l’escondeor SPIP. Aquò permet per exemple de forçar un calcul nòu de totas las paginas
s’avètz bravament modificat lo grafisme o l’estructura dau sit.',
	'texte_sur_titre' => 'Sobretítol',
	'texte_table_ok' => ': aquesta taula es condrecha.',
	'texte_tentative_recuperation' => 'Assai de reparacion',
	'texte_tenter_reparation' => 'Assajar de reparar la basa de donaas',
	'texte_test_proxy' => 'Per assajar aqueu proxy, indicatz aicí l’adreiça d’un sit web
    que lo voudriatz esprovar.',
	'texte_titre_02' => 'Títol:',
	'texte_titre_obligatoire' => '<b>Títol</b> [Obligatòri]',
	'texte_travail_article' => '@nom_auteur_modif@ a trabalhat sus aquel article aquò fai @date_diff@ minutas',
	'texte_travail_collaboratif' => 'Quand es frequent que mai d’un redactor 
  trabalhe sobre lo mesme article, lo sistèma
  pòt afichar los articles recentament "dubèrts"
  a fin d’evitar las modificacions simultanèas.
  Aquela opcion es desactivaa de maniera predefinia
  a fin d’evitar d’afichar de messatges d’avertiment
  intempestius.',
	'texte_vide' => 'voide',
	'texte_vider_cache' => 'Voidar l’escondeor',
	'titre_admin_tech' => 'Mantenença tecnica',
	'titre_admin_vider' => 'Mantenença tecnica',
	'titre_cadre_afficher_article' => 'Afichar los articles',
	'titre_cadre_afficher_traductions' => 'Afichar l’estat de las reviraas per las lengas seguentas:',
	'titre_cadre_ajouter_auteur' => 'APONDRE UN AUTOR:',
	'titre_cadre_interieur_rubrique' => 'Dedins la rubrica',
	'titre_cadre_numero_auteur' => 'AUTOR NUMÈRO',
	'titre_cadre_signature_obligatoire' => '<b>Signatura</b> [Obligatòria]<br />',
	'titre_config_fonctions' => 'Configuracion dau sit',
	'titre_configuration' => 'Configuracion dau sit',
	'titre_connexion_ldap' => 'Opcions: <b>Vòstra connexion LDAP</b>',
	'titre_groupe_mots' => 'GROP DE MOTS:',
	'titre_langue_article' => 'LENGA DE L’ARTICLE', # MODIF
	'titre_langue_rubrique' => 'LENGA DE LA RUBRICA', # MODIF
	'titre_langue_trad_article' => 'LENGA E REVIRAAS DE L’ARTICLE',
	'titre_les_articles' => 'LOS ARTICLES',
	'titre_naviguer_dans_le_site' => 'Navigar per lo sit...',
	'titre_nouvelle_rubrique' => 'Rubrica novèla',
	'titre_numero_rubrique' => 'RUBRICA NUMÈRO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Los articles',
	'titre_page_articles_tous' => 'Tot lo sit',
	'titre_page_calendrier' => 'Chalendier @nom_mois@ de @annee@',
	'titre_page_config_contenu' => 'Configuracion dau sit',
	'titre_page_delete_all' => 'supression totala e irreversibla',
	'titre_page_recherche' => 'Resultats de la cèrcha @recherche@',
	'titre_page_statistiques_referers' => 'Estadisticas (liams intrants)',
	'titre_page_upgrade' => 'Mesa a nivèu d’SPIP',
	'titre_publication_articles_post_dates' => 'Publicacion dels articles pòstdatats',
	'titre_reparation' => 'Reparacion',
	'titre_suivi_petition' => 'Seguit de las peticions',
	'trad_article_traduction' => 'Totas las versions d’aquel article:',
	'trad_delier' => 'Pas pus liar aquest article a sas reviraas ', # MODIF
	'trad_lier' => 'Aquest article es una reviraa de l’article numèro:',
	'trad_new' => 'Escriure una reviraa novèla d’aquest article' # MODIF
);
